# timber_design

Automation toolkit for the design of timber structures based on COMPAS timber

## Installation

Stable releases can be installed from PyPI.

```bash
pip install timber_design
```

To install the latest version for development, do:

```bash
git clone https://github.com/gramaziokohler/timber_design.git
cd timber_design
pip install -e ".[dev]"
```

## Documentation

For further "getting started" instructions, a tutorial, examples, and an API reference,
please check out the online documentation here: [timber_design docs](https://gramaziokohler.github.io/timber_design)

## Issue Tracker

If you find a bug or if you have a problem with running the code, please file an issue on the [Issue Tracker](https://github.com/gramaziokohler/timber_design/issues).
